@@ -37,6 +37,8 @@ class QTableWidget ;
 #include "siritask.h"
 #include "can_build_pwquality.h"
 #include "secrets.h"
+#include "securefscreateoptions.h"
+#include "cryfscreateoptions.h"
 
 #include <functional>
 #include <memory>
@@ -167,6 +169,7 @@ private :
 	QString m_exe ;
 	QString m_mountPointPath ;
 	QString m_mountOptions ;
+	QString m_createOptions ;
 	QStringList m_keyFiles ;
 
 	QTableWidget * m_table ;
@@ -174,6 +177,7 @@ private :
 	bool m_working ;
 	bool m_create ;
 	bool m_reUseMountPoint ;
+	bool m_checked = false ;
 
 	secrets& m_secrets ;
 
